@@ -136,94 +136,101 @@ GeoCV <- function(fit, K = 100, estimation = TRUE,
     ######################################################################
     #######  parallel version 
     ######################################################################
-    if (parallel) {
+if (parallel) {
+  
+  if (is.null(ncores)) {n.cores <- coremax - 1} 
+  else { 
+    if (!is.numeric(ncores) || ncores > coremax || ncores < 1)
+      stop("number of cores not valid\n")
+    n.cores <- ncores
+  }
+  cat("Performing", K, "cross-validations using", n.cores, "cores...\n")
+  
 
-      if (is.null(ncores)) {n.cores <- coremax - 1} 
-      else { if (!is.numeric(ncores) || ncores > coremax || ncores < 1)
-          stop("number of cores not valid\n")
-          n.cores <- ncores
-      }
+  # Configurazione future
+  future::plan(future::multisession, workers = n.cores)
+  on.exit(future::plan(sequential), add = TRUE)
+  
+  # Funzione per singola iterazione (senza caricamento pacchetti)
+  cv_iteration <- function(i) {
+    X <- Xloc <- Mloc <- NULL
+    sel_data <- sel_list[[i]]
     
-      future::plan(multisession, workers = n.cores)
-      on.exit(future::plan(sequential), add = TRUE)
-      progressr::handlers(global = TRUE)
-      progressr::handlers("txtprogressbar")
-      pb <- progressr::progressor(along = 1:K)
-      
-      cat("Performing", K, "cross-validations using", n.cores, "cores...\n")
-      
-################################################################
-############ starting foreach ##################################
-################################################################
-      results <- foreach::foreach(i = 1:K, .combine = 'rbind',
-                                   .options.future = list(seed = TRUE,stdout = NA,  
-                        conditions = character(0))) %dofuture% {
-     X <- Xloc <-Mloc<- NULL
-        sel_data <- sel_list[[i]]  # random sample
-
-
-  if (!is.null(fit$X)) {
-          X <- tempX[sel_data, ]
-          Xloc <- tempX[-sel_data, ]
-        } 
-
-        if (length(fit$fixed$mean) > 1) {
-          fit$fixed$mean <- tempM[sel_data]
-          Mloc <- tempM[-sel_data]
-        }
-        data_to_pred <- data[-sel_data]
-        data_to_est <- data[sel_data]
-        coords_est <- coords[sel_data, ]
-        coords_to_pred <- coords[-sel_data, ]
-
-        param <- c(fit$param, fit$fixed)
-
-        if (estimation) {
-          fit_s <- suppressWarnings(GeoFit(
-            data = data_to_est, coordx = coords_est, corrmodel = fit$corrmodel,
-            X = X, likelihood = fit$likelihood, type = fit$type,
-            grid = fit$grid, copula = fit$copula, anisopars = fit$anisopars,
-            est.aniso = fit$est.aniso, model = model1, radius = fit$radius,
-            n = fit$n, local = fit$local, GPU = fit$GPU,
-            maxdist = fit$maxdist, neighb = fit$neighb, distance = fit$distance,
-            optimizer = optimizer, lower = lower, upper = upper,
-            start = fit$param, fixed = fit$fixed
-          ))
-
-          if (!is.null(fit$anisopars)) {
-            fit_s$param$angle <- NULL; fit_s$param$ratio <- NULL
-            fit_s$fixed$angle <- NULL; fit_s$fixed$ratio <- NULL
-          }
-        #param <- append(fit_s$param, fit_s$fixed)
-        param <- c(fit_s$param, fit_s$fixed)
-        } 
-        else {fit_s <- fit}
-
-        if (!local) {
-          pr <- GeoKrig(fit_s, loc = coords_to_pred, mse = TRUE,
-                        param = param, Xloc = Xloc, Mloc = Mloc)
-        } else {
-          pr <- GeoKrigloc(fit_s, loc = coords_to_pred, mse = TRUE,
-                           param = param, Xloc = Xloc, Mloc = Mloc,
-                           neighb = neighb, maxdist = maxdist,progress=FALSE)
-        }
-
-        pp <- GeoScores(data_to_pred, pred = pr$pred, mse = pr$mse,
-                        score = c("brie", "crps", "lscore", "pe"))
-
-        pb(sprintf("i=%g", i))
-
-        return(c(pp$rmse, pp$mae, pp$mad, pp$lscore, pp$brie, pp$crps))
-      }
-
-      rmse <- unname(results[, 1])
-      mae <- unname(results[, 2])
-      mad <- unname(results[, 3])
-      lscore <- unname(results[, 4])
-      brie <- unname(results[, 5])
-      crps <- unname(results[, 6])
-
+    if (!is.null(fit$X)) {
+      X <- tempX[sel_data, ]
+      Xloc <- tempX[-sel_data, ]
+    } 
+    
+    if (length(fit$fixed$mean) > 1) {
+      fit$fixed$mean <- tempM[sel_data]
+      Mloc <- tempM[-sel_data]
     }
+    
+    data_to_pred <- data[-sel_data]
+    data_to_est <- data[sel_data]
+    coords_est <- coords[sel_data, ]
+    coords_to_pred <- coords[-sel_data, ]
+    
+    param <- c(fit$param, fit$fixed)
+    
+    if (estimation) {
+      fit_s <- suppressWarnings(GeoFit(
+        data = data_to_est, coordx = coords_est, corrmodel = fit$corrmodel,
+        X = X, likelihood = fit$likelihood, type = fit$type,
+        grid = fit$grid, copula = fit$copula, anisopars = fit$anisopars,
+        est.aniso = fit$est.aniso, model = model1, radius = fit$radius,
+        n = fit$n, 
+        maxdist = fit$maxdist, neighb = fit$neighb, distance = fit$distance,
+        optimizer = optimizer, lower = lower, upper = upper,
+        start = fit$param, fixed = fit$fixed
+      ))
+      
+      if (!is.null(fit$anisopars)) {
+        fit_s$param$angle <- NULL; fit_s$param$ratio <- NULL
+        fit_s$fixed$angle <- NULL; fit_s$fixed$ratio <- NULL
+      }
+      param <- c(fit_s$param, fit_s$fixed)
+    } else {
+      fit_s <- fit
+    }
+    
+    if (!local) {
+      pr <- GeoKrig(fit_s, loc = coords_to_pred, mse = TRUE,
+                    param = param, Xloc = Xloc, Mloc = Mloc)
+    } else {
+      pr <- GeoKrigloc(fit_s, loc = coords_to_pred, mse = TRUE,
+                       param = param, Xloc = Xloc, Mloc = Mloc,
+                       neighb = neighb, maxdist = maxdist, progress = FALSE)
+    }
+    
+    pp <- GeoScores(data_to_pred, pred = pr$pred, mse = pr$mse,
+                    score = c("brie", "crps", "lscore", "pe"))
+    
+    return(c(pp$rmse, pp$mae, pp$mad, pp$lscore, pp$brie, pp$crps))
+  }
+  
+  # Esecuzione parallela con progress bar
+  cat("Starting cross-validation iterations...\n")
+  progressr::with_progress({
+    pb <- progressr::progressor(steps = K)
+    
+    results <- future.apply::future_lapply(1:K, function(i) {
+      result <- cv_iteration(i)
+      pb(sprintf("Completed iteration %d/%d", i, K))
+      return(result)
+    }, future.seed = TRUE, future.stdout = FALSE,
+        future.conditions = "none")
+  })
+  
+  # Conversione risultati
+  results_matrix <- do.call(rbind, results)
+  rmse <- results_matrix[, 1]
+  mae <- results_matrix[, 2]
+  mad <- results_matrix[, 3]
+  lscore <- results_matrix[, 4]
+  brie <- results_matrix[, 5]
+  crps <- results_matrix[, 6]
+}
   }
 
 ############################################################
@@ -408,6 +415,7 @@ if (!parallel) {
 }### End Not Parallel
 
 ######################  parallel case ############################
+######################  SPACETIME PARALLEL VERSION - FIXED ############################
 if (parallel) {
   
   if (is.null(ncores)) {n.cores <- coremax - 1} 
@@ -417,134 +425,138 @@ if (parallel) {
     n.cores <- ncores
   }
   
-
-      future::plan(multisession, workers = n.cores)
-      on.exit(future::plan(sequential), add = TRUE)
-      progressr::handlers(global = TRUE)
-      progressr::handlers("txtprogressbar")
-      pb <- progressr::progressor(along = 1:K)
-      
-      cat("Performing", K, "cross-validations using", n.cores, "cores...\n")
+  cat("Performing", K, "cross-validations using", n.cores, "cores...\n")
   
-      results <- foreach(i = 1:K,
-                   .combine = 'rbind',  
-                   .options.future = list(seed = TRUE,stdout = NA,  
-                        conditions = character(0))) %dofuture% {
-
-    test_idx = folds[[i]]
-    train_idx = setdiff(1:NT, test_idx)
-
-    data_sel = data_tot[train_idx, ]
-    data_to_pred = data_tot[test_idx, ]
-
-    if (is.vector(data_to_pred)) data_to_pred = matrix(data_to_pred, nrow = 1)
-    if (is.vector(data_sel)) data_sel = matrix(data_sel, nrow = 1)
-
-    data_sel_ord = as.matrix(data_sel[order(data_sel[, 1]), ])
-    data_to_pred_ord = as.matrix(data_to_pred[order(data_to_pred[, 1]), ])
-
-    DD = ncol(data_sel_ord)
-    coordx_dynnew = Xnew = Xnew_loc = datanew = coordx_dynnew_loc = list()
-
-    utt = unique(data_sel_ord[, 1])
-    utt_1 = unique(data_to_pred_ord[, 1])
-
-  Xnew_loc=Mnew_loc=NULL
+  # Configurazione future
+  future::plan(future::multisession, workers = n.cores)
+  on.exit(future::plan(sequential), add = TRUE)
+  
+  # Funzione per singola iterazione spazio-temporale (senza caricamento pacchetti)
+  cv_iteration_st <- function(i) {
+    test_idx <- folds[[i]]
+    train_idx <- setdiff(1:NT, test_idx)
+    
+    data_sel <- data_tot[train_idx, ]
+    data_to_pred <- data_tot[test_idx, ]
+    
+    if (is.vector(data_to_pred)) data_to_pred <- matrix(data_to_pred, nrow = 1)
+    if (is.vector(data_sel)) data_sel <- matrix(data_sel, nrow = 1)
+    
+    data_sel_ord <- as.matrix(data_sel[order(data_sel[, 1]), ])
+    data_to_pred_ord <- as.matrix(data_to_pred[order(data_to_pred[, 1]), ])
+    
+    DD <- ncol(data_sel_ord)
+    coordx_dynnew <- Xnew <- Xnew_loc <- datanew <- coordx_dynnew_loc <- list()
+    
+    utt <- unique(data_sel_ord[, 1])
+    utt_1 <- unique(data_to_pred_ord[, 1])
+    
+    Xnew_loc <- Mnew_loc <- NULL
     for (k in 1:length(utt_1)) {
-      ll = data_to_pred_ord[data_to_pred_ord[, 1] == utt_1[k], , drop = FALSE]
-   
+      ll <- data_to_pred_ord[data_to_pred_ord[, 1] == utt_1[k], , drop = FALSE]
+      
       if (ncol(ll) >= 3) {
-        if (!is.null(fit$coordz))  # 3d
-        {
-              coordx_dynnew_loc[[k]] = matrix(ll[, 2:4], ncol = 3)
-              if(!MM){if (!is.null(X)) Xnew_loc[[k]] = matrix(ll[, 6:DD], ncol = DD - 5)}
-                else   {Mnew_loc[[k]] = ll[, 6]}
-        } 
-      else {                     #2d
-          coordx_dynnew_loc[[k]] = matrix(ll[, 2:3], ncol = 2)
-           if(!MM){ if (!is.null(X)) Xnew_loc[[k]] = matrix(ll[, 5:DD], ncol = DD - 4) }
-           else   {Mnew_loc[[k]] = ll[, 6]}
+        if (!is.null(fit$coordz)) {
+          coordx_dynnew_loc[[k]] <- matrix(ll[, 2:4], ncol = 3)
+          if(!MM) {
+            if (!is.null(X)) Xnew_loc[[k]] <- matrix(ll[, 6:DD], ncol = DD - 5)
+          } else {
+            Mnew_loc[[k]] <- ll[, 6]
+          }
+        } else {
+          coordx_dynnew_loc[[k]] <- matrix(ll[, 2:3], ncol = 2)
+          if(!MM) {
+            if (!is.null(X)) Xnew_loc[[k]] <- matrix(ll[, 5:DD], ncol = DD - 4)
+          } else {
+            Mnew_loc[[k]] <- ll[, 6]
+          }
         }
       } 
     }
- 
-     Xnew = NULL
+    
+    Xnew <- NULL
     for (k in 1:length(utt)) {
-      ss = data_sel_ord[data_sel_ord[, 1] == utt[k], , drop = FALSE]
+      ss <- data_sel_ord[data_sel_ord[, 1] == utt[k], , drop = FALSE]
       if (!is.null(fit$coordz)) {
-        coordx_dynnew[[k]] = matrix(ss[, 2:4], ncol = 3)
-        datanew[[k]] = as.vector(ss[, 5])
-        if (!is.null(X)) Xnew[[k]] = matrix(ss[, 6:DD], ncol = DD - 5)
+        coordx_dynnew[[k]] <- matrix(ss[, 2:4], ncol = 3)
+        datanew[[k]] <- as.vector(ss[, 5])
+        if (!is.null(X)) Xnew[[k]] <- matrix(ss[, 6:DD], ncol = DD - 5)
       } else {
-        coordx_dynnew[[k]] = matrix(ss[, 2:3], ncol = 2)
-        datanew[[k]] = as.vector(ss[, 4])
-        if (!is.null(X)) Xnew[[k]] = matrix(ss[, 5:DD], ncol = DD - 4)
+        coordx_dynnew[[k]] <- matrix(ss[, 2:3], ncol = 2)
+        datanew[[k]] <- as.vector(ss[, 4])
+        if (!is.null(X)) Xnew[[k]] <- matrix(ss[, 5:DD], ncol = DD - 4)
       }
     }
-
-    #param = append(fit$param, fit$fixed)
-    param = c(fit$param, fit$fixed)
-
+    
+    param <- c(fit$param, fit$fixed)
+    
     if (estimation) {
-      fit_s = suppressWarnings(GeoFit(data = datanew, coordx_dyn = coordx_dynnew, coordt = utt,
-                     corrmodel = fit$corrmodel, X = Xnew, likelihood = fit$likelihood, 
-                     type = fit$type, grid = fit$grid, copula = fit$copula, 
-                     anisopars = fit$anisopars, est.aniso = fit$est.aniso,
-                     model = model1, radius = fit$radius, n = fit$n,
-                     maxdist = fit$maxdist, neighb = fit$neighb, maxtime = fit$maxtime, 
-                     distance = fit$distance, optimizer = optimizer, 
-                     lower = lower, upper = upper,
-                     start = fit$param, fixed = fit$fixed))
-
+      fit_s <- suppressWarnings(GeoFit(
+        data = datanew, coordx_dyn = coordx_dynnew, coordt = utt,
+        corrmodel = fit$corrmodel, X = Xnew, likelihood = fit$likelihood, 
+        type = fit$type, grid = fit$grid, copula = fit$copula, 
+        anisopars = fit$anisopars, est.aniso = fit$est.aniso,
+        model = model1, radius = fit$radius, n = fit$n,
+        maxdist = fit$maxdist, neighb = fit$neighb, maxtime = fit$maxtime, 
+        distance = fit$distance, optimizer = optimizer, 
+        lower = lower, upper = upper,
+        start = fit$param, fixed = fit$fixed
+      ))
+      
       if (!is.null(fit$anisopars)) {
-        fit_s$param$angle = NULL
-        fit_s$param$ratio = NULL
-        fit_s$fixed$angle = NULL
-        fit_s$fixed$ratio = NULL
+        fit_s$param$angle <- NULL; fit_s$param$ratio <- NULL
+        fit_s$fixed$angle <- NULL; fit_s$fixed$ratio <- NULL
       }
-
-      #param = append(fit_s$param, fit_s$fixed)
-      param = c(fit_s$param, fit_s$fixed)
+      param <- c(fit_s$param, fit_s$fixed)
     }
-
-    pr_st = pr_mse = list()
+    
+    pr_st <- pr_mse <- list()
     for (j in 1:length(utt_1)) {
-      if (is.null(Xnew)) Xnew_loc[j] = list(NULL)
-
+      if (is.null(Xnew)) Xnew_loc[j] <- list(NULL)
+      
       if (!local) {
-        pr = GeoKrig(fit_s, loc = coordx_dynnew_loc[[j]], 
-                     param = param, time = utt_1[j], mse = TRUE, Mloc=Mnew_loc[[j]],
+        pr <- GeoKrig(fit_s, loc = coordx_dynnew_loc[[j]], 
+                     param = param, time = utt_1[j], mse = TRUE, Mloc = Mnew_loc[[j]],
                      Xloc = Xnew_loc[[j]])
       } else {
-        pr = GeoKrigloc(fit_s, loc = coordx_dynnew_loc[[j]], 
-                        param = param, time = utt_1[j], mse = TRUE,  Mloc=Mnew_loc[[j]],
-                        neighb = neighb, maxdist = maxdist, maxtime = maxtime, progress=FALSE,
+        pr <- GeoKrigloc(fit_s, loc = coordx_dynnew_loc[[j]], 
+                        param = param, time = utt_1[j], mse = TRUE, Mloc = Mnew_loc[[j]],
+                        neighb = neighb, maxdist = maxdist, maxtime = maxtime, progress = FALSE,
                         Xloc = Xnew_loc[[j]])
       }
-
-      pr_st[[j]] = pr$pred
-      pr_mse[[j]] = pr$mse
+      
+      pr_st[[j]] <- pr$pred
+      pr_mse[[j]] <- pr$mse
     }
-
-
-  pp = GeoScores(c(data_to_pred[, 4]), pred = as.numeric(unlist(pr_st)), 
+    
+    pp <- GeoScores(c(data_to_pred[, 4]), pred = as.numeric(unlist(pr_st)), 
                    mse = as.numeric(unlist(pr_mse)),
                    score = c("brie", "crps", "lscore", "pe"))
     
-   
-    pb(sprintf("i=%g", i))
-    # Restituisce un vettore numerico invece di una lista
-    c(pp$rmse, pp$mae, pp$mad, pp$lscore, pp$brie, pp$crps)
-
+    return(c(pp$rmse, pp$mae, pp$mad, pp$lscore, pp$brie, pp$crps))
   }
   
-  # Estrazione dei risultati dalla matrice
-  rmse = unname(results[, 1])
-  mae = unname(results[, 2])
-  mad = unname(results[, 3])
-  lscore = unname(results[, 4])
-  brie = unname(results[, 5])
-  crps = unname(results[, 6])
+  # Esecuzione parallela con progress bar
+  cat("Starting cross-validation iterations...\n")
+  progressr::with_progress({
+    pb <- progressr::progressor(steps = K)
+    
+    results <- future.apply::future_lapply(1:K, function(i) {
+      result <- cv_iteration_st(i)
+      pb(sprintf("Completed iteration %d/%d", i, K))
+      return(result)
+    }, future.seed = TRUE, future.stdout = FALSE,
+        future.conditions = "none")
+  })
+  
+  # Conversione risultati
+  results_matrix <- do.call(rbind, results)
+  rmse <- results_matrix[, 1]
+  mae <- results_matrix[, 2]
+  mad <- results_matrix[, 3]
+  lscore <- results_matrix[, 4]
+  brie <- results_matrix[, 5]
+  crps <- results_matrix[, 6]
 }
 
 } ## end spacetime
@@ -655,7 +667,7 @@ if (bivariate) {
         append(fit$param, current_fixed)
       }
 
-print(fit_s$copula)
+
       pr <- if (!local) {
         GeoKrig(fit_s,
            coordx = NULL, 
@@ -688,8 +700,8 @@ print(fit_s$copula)
   } 
 
   # ==================== VERSIONE PARALLELA ====================
-  if(parallel) {   
-
+## spatial bivariate case
+if (parallel) {   
   
   if (is.null(ncores)) {n.cores <- coremax - 1} 
   else { 
@@ -697,110 +709,119 @@ print(fit_s$copula)
       stop("number of cores not valid\n")
     n.cores <- ncores
   }
-
-    samples <- lapply(1:K, function(i) {
-                      if (which == 1) { sample(1:ns[1], round(ns[1] * (1 - n.fold)))} 
-                      else {sample(1:ns[2], round(ns[2] * (1 - n.fold)))}
-                       })
-    future::plan(future::multisession, workers = n.cores)
-    on.exit(future::plan(sequential), add = TRUE)
-
-    progressr::handlers(global = TRUE)
-    progressr::handlers("txtprogressbar")
-    pb <- progressr::progressor(along = 1:K)
-       cat("Performing", K, "cross-validations using", n.cores, "cores...\n")
-    
-    ############################################ 
-    ########### starting foreach ############### 
-    ############################################
-    results <- foreach::foreach(i = 1:K,.combine = rbind,.options.future = list(seed =TRUE,stdout = NA,  
-                        conditions = character(0))  ) %dofuture% {
-
-      sel_data <- samples[[i]] ##### sample!
-      
-      if (which == 1) {
-        data_to_est <- list(data1[sel_data], data2)
-        data_to_pred <- data1[-sel_data]
-        coords_est <- list(coords1[sel_data, ], coords2)
-        coords_pred <- coords1[-sel_data, ]
-        X_use <- if (!is.null(X1)) rbind(X1[sel_data, ], X2) else NULL
-        Xloc_use <- if (!is.null(X1)) rbind(X1[-sel_data, ], X2) else NULL
-        
-        if (fixmeans) {
-          current_fixed <- fit$fixed
-          current_fixed$mean_1 <- tempM1[sel_data]
-          Mloc <- list(tempM1[-sel_data], tempM2)
-        } else {
-          current_fixed <- fit$fixed
-          Mloc <- NULL
-        }
-      } else {
-        data_to_est <- list(data1, data2[sel_data])
-        data_to_pred <- data2[-sel_data]
-        coords_est <- list(coords1, coords2[sel_data, ])
-        coords_pred <- coords2[-sel_data, ]
-        
-        X_use <- if (!is.null(X2)) rbind(X1, X2[sel_data, ]) else NULL
-        Xloc_use <- if (!is.null(X2)) rbind(X1, X2[-sel_data, ]) else NULL
-        
-        if (fixmeans) {
-          current_fixed <- fit$fixed
-          current_fixed$mean_2 <- tempM2[sel_data]
-          Mloc <- list(tempM1, tempM2[-sel_data])
-        } else {
-          current_fixed <- fit$fixed
-          Mloc <- NULL
-        }
-      }
-
-      param <- if (estimation) {
-        fit_s <- suppressWarnings(GeoFit(
-          data = data_to_est, coordx = NULL, coordx_dyn = coords_est,
-          corrmodel = fit$corrmodel, X = X_use,
-          likelihood = fit$likelihood, type = fit$type, grid = fit$grid,
-          model = "Gaussian", radius = fit$radius, n = fit$n,
-          copula = fit$copula, 
-          maxdist = fit$maxdist, neighb = fit$neighb, distance = fit$distance,
-          optimizer = optimizer, lower = lower, upper = upper,
-          start = fit$param, fixed = current_fixed
-        ))
-        if (!is.null(fit$anisopars)) {
-          fit_s$param$angle <- fit_s$param$ratio <- NULL
-          fit_s$fixed$angle <- fit_s$fixed$ratio <- NULL
-        }
-        append(fit_s$param, fit_s$fixed)
-      } else {
-        append(fit$param, current_fixed)
-      }
-
-      pr <- if (!local) {
-        GeoKrig(fit_s,
-          loc = coords_pred,mse = TRUE,
-          param = param, Xloc = Xloc_use, Mloc = Mloc, which = which)
-      } else {
-        GeoKrigloc(fit_s,
-          loc = coords_pred,mse = TRUE,
-           neighb = neighb, maxdist = maxdist,
-          param = param, Xloc = Xloc_use, Mloc = Mloc, which = which,progress=FALSE)
-      }
-      
-      scores <- GeoScores(
-        data_to_pred, pred = pr$pred, mse = pr$mse,
-        score = c("brie", "crps", "lscore", "pe")
-      )
-      pb(sprintf("i=%g", i))
-      c(scores$rmse, scores$mae, scores$mad, 
-        scores$lscore, scores$brie, scores$crps)
-    }
   
-
-    rmse <- unname(results[, 1])
-    mae <- unname(results[, 2])
-    mad <- unname(results[, 3])
-    lscore <- unname(results[, 4])
-    brie <- unname(results[, 5])
-    crps <- unname(results[, 6])
+  cat("Performing", K, "cross-validations using", n.cores, "cores...\n")
+  
+  # Pre-generazione dei campioni
+  samples <- lapply(1:K, function(i) {
+    if (which == 1) { 
+      sample(1:ns[1], round(ns[1] * (1 - n.fold)))
+    } else {
+      sample(1:ns[2], round(ns[2] * (1 - n.fold)))
+    }
+  })
+  
+  # Configurazione future
+  future::plan(future::multisession, workers = n.cores)
+  on.exit(future::plan(sequential), add = TRUE)
+   
+  # Funzione per singola iterazione bivariata (senza caricamento pacchetti)
+  cv_iteration_biv <- function(i) {
+    sel_data <- samples[[i]]
+    
+    if (which == 1) {
+      data_to_est <- list(data1[sel_data], data2)
+      data_to_pred <- data1[-sel_data]
+      coords_est <- list(coords1[sel_data, ], coords2)
+      coords_pred <- coords1[-sel_data, ]
+      X_use <- if (!is.null(X1)) rbind(X1[sel_data, ], X2) else NULL
+      Xloc_use <- if (!is.null(X1)) rbind(X1[-sel_data, ], X2) else NULL
+      
+      if (fixmeans) {
+        current_fixed <- fit$fixed
+        current_fixed$mean_1 <- tempM1[sel_data]
+        Mloc <- list(tempM1[-sel_data], tempM2)
+      } else {
+        current_fixed <- fit$fixed
+        Mloc <- NULL
+      }
+    } else {
+      data_to_est <- list(data1, data2[sel_data])
+      data_to_pred <- data2[-sel_data]
+      coords_est <- list(coords1, coords2[sel_data, ])
+      coords_pred <- coords2[-sel_data, ]
+      
+      X_use <- if (!is.null(X2)) rbind(X1, X2[sel_data, ]) else NULL
+      Xloc_use <- if (!is.null(X2)) rbind(X1, X2[-sel_data, ]) else NULL
+      
+      if (fixmeans) {
+        current_fixed <- fit$fixed
+        current_fixed$mean_2 <- tempM2[sel_data]
+        Mloc <- list(tempM1, tempM2[-sel_data])
+      } else {
+        current_fixed <- fit$fixed
+        Mloc <- NULL
+      }
+    }
+    
+    param <- if (estimation) {
+      fit_s <- suppressWarnings(GeoFit(
+        data = data_to_est, coordx = NULL, coordx_dyn = coords_est,
+        corrmodel = fit$corrmodel, X = X_use,
+        likelihood = fit$likelihood, type = fit$type, grid = fit$grid,
+        model = "Gaussian", radius = fit$radius, n = fit$n,
+        copula = fit$copula, 
+        maxdist = fit$maxdist, neighb = fit$neighb, distance = fit$distance,
+        optimizer = optimizer, lower = lower, upper = upper,
+        start = fit$param, fixed = current_fixed
+      ))
+      if (!is.null(fit$anisopars)) {
+        fit_s$param$angle <- fit_s$param$ratio <- NULL
+        fit_s$fixed$angle <- fit_s$fixed$ratio <- NULL
+      }
+      append(fit_s$param, fit_s$fixed)
+    } else {
+      append(fit$param, current_fixed)
+    }
+    
+    pr <- if (!local) {
+      GeoKrig(fit_s, loc = coords_pred, mse = TRUE,
+              param = param, Xloc = Xloc_use, Mloc = Mloc, which = which)
+    } else {
+      GeoKrigloc(fit_s, loc = coords_pred, mse = TRUE,
+                 neighb = neighb, maxdist = maxdist,
+                 param = param, Xloc = Xloc_use, Mloc = Mloc, which = which, progress = FALSE)
+    }
+    
+    scores <- GeoScores(data_to_pred, pred = pr$pred, mse = pr$mse,
+                       score = c("brie", "crps", "lscore", "pe"))
+    
+    return(c(scores$rmse, scores$mae, scores$mad, 
+             scores$lscore, scores$brie, scores$crps))
   }
+  
+  # Esecuzione parallela con progress bar
+  cat("Starting cross-validation iterations...\n")
+  progressr::with_progress({
+    pb <- progressr::progressor(steps = K)
+    
+    results <- future.apply::future_lapply(1:K, function(i) {
+      result <- cv_iteration_biv(i)
+      pb(sprintf("Completed iteration %d/%d", i, K))
+      return(result)
+    }, future.seed = TRUE, future.stdout = FALSE,
+        future.conditions = "none")
+  })
+  
+  # Conversione risultati
+  results_matrix <- do.call(rbind, results)
+  rmse <- results_matrix[, 1]
+  mae <- results_matrix[, 2]
+  mad <- results_matrix[, 3]
+  lscore <- results_matrix[, 4]
+  brie <- results_matrix[, 5]
+  crps <- results_matrix[, 6]
+}
 }  # end bivariate
 
 return(list(rmse=rmse,mae=mae,mad=mad,brie=brie,crps=crps,lscore=lscore))
